# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/detection.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.automl_v1beta1.proto import (
    geometry_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_geometry__pb2,
)
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/detection.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1P\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n1google/cloud/automl_v1beta1/proto/detection.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x30google/cloud/automl_v1beta1/proto/geometry.proto\x1a\x1egoogle/protobuf/duration.proto"p\n\x1eImageObjectDetectionAnnotation\x12?\n\x0c\x62ounding_box\x18\x01 \x01(\x0b\x32).google.cloud.automl.v1beta1.BoundingPoly\x12\r\n\x05score\x18\x02 \x01(\x02"\xae\x02\n\x17\x42oundingBoxMetricsEntry\x12\x15\n\riou_threshold\x18\x01 \x01(\x02\x12\x1e\n\x16mean_average_precision\x18\x02 \x01(\x02\x12o\n\x1a\x63onfidence_metrics_entries\x18\x03 \x03(\x0b\x32K.google.cloud.automl.v1beta1.BoundingBoxMetricsEntry.ConfidenceMetricsEntry\x1ak\n\x16\x43onfidenceMetricsEntry\x12\x1c\n\x14\x63onfidence_threshold\x18\x01 \x01(\x02\x12\x0e\n\x06recall\x18\x02 \x01(\x02\x12\x11\n\tprecision\x18\x03 \x01(\x02\x12\x10\n\x08\x66\x31_score\x18\x04 \x01(\x02"\xd6\x01\n%ImageObjectDetectionEvaluationMetrics\x12$\n\x1c\x65valuated_bounding_box_count\x18\x01 \x01(\x05\x12Z\n\x1c\x62ounding_box_metrics_entries\x18\x02 \x03(\x0b\x32\x34.google.cloud.automl.v1beta1.BoundingBoxMetricsEntry\x12+\n#bounding_box_mean_average_precision\x18\x03 \x01(\x02\x42\x84\x01\n\x1f\x63om.google.cloud.automl.v1beta1P\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_geometry__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,
    ],
)


_IMAGEOBJECTDETECTIONANNOTATION = _descriptor.Descriptor(
    name="ImageObjectDetectionAnnotation",
    full_name="google.cloud.automl.v1beta1.ImageObjectDetectionAnnotation",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="bounding_box",
            full_name="google.cloud.automl.v1beta1.ImageObjectDetectionAnnotation.bounding_box",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="score",
            full_name="google.cloud.automl.v1beta1.ImageObjectDetectionAnnotation.score",
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=194,
    serialized_end=306,
)


_BOUNDINGBOXMETRICSENTRY_CONFIDENCEMETRICSENTRY = _descriptor.Descriptor(
    name="ConfidenceMetricsEntry",
    full_name="google.cloud.automl.v1beta1.BoundingBoxMetricsEntry.ConfidenceMetricsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="confidence_threshold",
            full_name="google.cloud.automl.v1beta1.BoundingBoxMetricsEntry.ConfidenceMetricsEntry.confidence_threshold",
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="recall",
            full_name="google.cloud.automl.v1beta1.BoundingBoxMetricsEntry.ConfidenceMetricsEntry.recall",
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="precision",
            full_name="google.cloud.automl.v1beta1.BoundingBoxMetricsEntry.ConfidenceMetricsEntry.precision",
            index=2,
            number=3,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="f1_score",
            full_name="google.cloud.automl.v1beta1.BoundingBoxMetricsEntry.ConfidenceMetricsEntry.f1_score",
            index=3,
            number=4,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=504,
    serialized_end=611,
)

_BOUNDINGBOXMETRICSENTRY = _descriptor.Descriptor(
    name="BoundingBoxMetricsEntry",
    full_name="google.cloud.automl.v1beta1.BoundingBoxMetricsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="iou_threshold",
            full_name="google.cloud.automl.v1beta1.BoundingBoxMetricsEntry.iou_threshold",
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="mean_average_precision",
            full_name="google.cloud.automl.v1beta1.BoundingBoxMetricsEntry.mean_average_precision",
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="confidence_metrics_entries",
            full_name="google.cloud.automl.v1beta1.BoundingBoxMetricsEntry.confidence_metrics_entries",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_BOUNDINGBOXMETRICSENTRY_CONFIDENCEMETRICSENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=309,
    serialized_end=611,
)


_IMAGEOBJECTDETECTIONEVALUATIONMETRICS = _descriptor.Descriptor(
    name="ImageObjectDetectionEvaluationMetrics",
    full_name="google.cloud.automl.v1beta1.ImageObjectDetectionEvaluationMetrics",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="evaluated_bounding_box_count",
            full_name="google.cloud.automl.v1beta1.ImageObjectDetectionEvaluationMetrics.evaluated_bounding_box_count",
            index=0,
            number=1,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="bounding_box_metrics_entries",
            full_name="google.cloud.automl.v1beta1.ImageObjectDetectionEvaluationMetrics.bounding_box_metrics_entries",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="bounding_box_mean_average_precision",
            full_name="google.cloud.automl.v1beta1.ImageObjectDetectionEvaluationMetrics.bounding_box_mean_average_precision",
            index=2,
            number=3,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=614,
    serialized_end=828,
)

_IMAGEOBJECTDETECTIONANNOTATION.fields_by_name[
    "bounding_box"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_geometry__pb2._BOUNDINGPOLY
)
_BOUNDINGBOXMETRICSENTRY_CONFIDENCEMETRICSENTRY.containing_type = (
    _BOUNDINGBOXMETRICSENTRY
)
_BOUNDINGBOXMETRICSENTRY.fields_by_name[
    "confidence_metrics_entries"
].message_type = _BOUNDINGBOXMETRICSENTRY_CONFIDENCEMETRICSENTRY
_IMAGEOBJECTDETECTIONEVALUATIONMETRICS.fields_by_name[
    "bounding_box_metrics_entries"
].message_type = _BOUNDINGBOXMETRICSENTRY
DESCRIPTOR.message_types_by_name[
    "ImageObjectDetectionAnnotation"
] = _IMAGEOBJECTDETECTIONANNOTATION
DESCRIPTOR.message_types_by_name["BoundingBoxMetricsEntry"] = _BOUNDINGBOXMETRICSENTRY
DESCRIPTOR.message_types_by_name[
    "ImageObjectDetectionEvaluationMetrics"
] = _IMAGEOBJECTDETECTIONEVALUATIONMETRICS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ImageObjectDetectionAnnotation = _reflection.GeneratedProtocolMessageType(
    "ImageObjectDetectionAnnotation",
    (_message.Message,),
    dict(
        DESCRIPTOR=_IMAGEOBJECTDETECTIONANNOTATION,
        __module__="google.cloud.automl_v1beta1.proto.detection_pb2",
        __doc__="""Annotation details for image object detection.
  
  
  Attributes:
      bounding_box:
          Output only. The rectangle representing the object location.
      score:
          Output only. The confidence that this annotation is positive
          for the parent example, value in [0, 1], higher means higher
          positivity confidence.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ImageObjectDetectionAnnotation)
    ),
)
_sym_db.RegisterMessage(ImageObjectDetectionAnnotation)

BoundingBoxMetricsEntry = _reflection.GeneratedProtocolMessageType(
    "BoundingBoxMetricsEntry",
    (_message.Message,),
    dict(
        ConfidenceMetricsEntry=_reflection.GeneratedProtocolMessageType(
            "ConfidenceMetricsEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_BOUNDINGBOXMETRICSENTRY_CONFIDENCEMETRICSENTRY,
                __module__="google.cloud.automl_v1beta1.proto.detection_pb2",
                __doc__="""Metrics for a single confidence threshold.
    
    
    Attributes:
        confidence_threshold:
            Output only. The confidence threshold value used to compute
            the metrics.
        recall:
            Output only. Recall under the given confidence threshold.
        precision:
            Output only. Precision under the given confidence threshold.
        f1_score:
            Output only. The harmonic mean of recall and precision.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.BoundingBoxMetricsEntry.ConfidenceMetricsEntry)
            ),
        ),
        DESCRIPTOR=_BOUNDINGBOXMETRICSENTRY,
        __module__="google.cloud.automl_v1beta1.proto.detection_pb2",
        __doc__="""Bounding box matching model metrics for a single intersection-over-union
  threshold and multiple label match confidence thresholds.
  
  
  Attributes:
      iou_threshold:
          Output only. The intersection-over-union threshold value used
          to compute this metrics entry.
      mean_average_precision:
          Output only. The mean average precision, most often close to
          au\_prc.
      confidence_metrics_entries:
          Output only. Metrics for each label-match
          confidence\_threshold from
          0.05,0.10,...,0.95,0.96,0.97,0.98,0.99. Precision-recall curve
          is derived from them.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.BoundingBoxMetricsEntry)
    ),
)
_sym_db.RegisterMessage(BoundingBoxMetricsEntry)
_sym_db.RegisterMessage(BoundingBoxMetricsEntry.ConfidenceMetricsEntry)

ImageObjectDetectionEvaluationMetrics = _reflection.GeneratedProtocolMessageType(
    "ImageObjectDetectionEvaluationMetrics",
    (_message.Message,),
    dict(
        DESCRIPTOR=_IMAGEOBJECTDETECTIONEVALUATIONMETRICS,
        __module__="google.cloud.automl_v1beta1.proto.detection_pb2",
        __doc__="""Model evaluation metrics for image object detection problems. Evaluates
  prediction quality of labeled bounding boxes.
  
  
  Attributes:
      evaluated_bounding_box_count:
          Output only. The total number of bounding boxes (i.e. summed
          over all images) the ground truth used to create this
          evaluation had.
      bounding_box_metrics_entries:
          Output only. The bounding boxes match metrics for each
          Intersection-over-union threshold
          0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each label
          confidence threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99
          pair.
      bounding_box_mean_average_precision:
          Output only. The single metric for bounding boxes evaluation:
          the mean\_average\_precision averaged over all
          bounding\_box\_metrics\_entries.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ImageObjectDetectionEvaluationMetrics)
    ),
)
_sym_db.RegisterMessage(ImageObjectDetectionEvaluationMetrics)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/prediction_service.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.automl_v1beta1.proto import (
    annotation_payload_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_annotation__payload__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    data_items_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__items__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    io_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    operations_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_operations__pb2,
)
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/prediction_service.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1B\026PredictionServiceProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n:google/cloud/automl_v1beta1/proto/prediction_service.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a:google/cloud/automl_v1beta1/proto/annotation_payload.proto\x1a\x32google/cloud/automl_v1beta1/proto/data_items.proto\x1a*google/cloud/automl_v1beta1/proto/io.proto\x1a\x32google/cloud/automl_v1beta1/proto/operations.proto\x1a#google/longrunning/operations.proto"\xd4\x01\n\x0ePredictRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12<\n\x07payload\x18\x02 \x01(\x0b\x32+.google.cloud.automl.v1beta1.ExamplePayload\x12G\n\x06params\x18\x03 \x03(\x0b\x32\x37.google.cloud.automl.v1beta1.PredictRequest.ParamsEntry\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xd1\x01\n\x0fPredictResponse\x12?\n\x07payload\x18\x01 \x03(\x0b\x32..google.cloud.automl.v1beta1.AnnotationPayload\x12L\n\x08metadata\x18\x02 \x03(\x0b\x32:.google.cloud.automl.v1beta1.PredictResponse.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\xba\x02\n\x13\x42\x61tchPredictRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12J\n\x0cinput_config\x18\x03 \x01(\x0b\x32\x34.google.cloud.automl.v1beta1.BatchPredictInputConfig\x12L\n\routput_config\x18\x04 \x01(\x0b\x32\x35.google.cloud.automl.v1beta1.BatchPredictOutputConfig\x12L\n\x06params\x18\x05 \x03(\x0b\x32<.google.cloud.automl.v1beta1.BatchPredictRequest.ParamsEntry\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\x14\n\x12\x42\x61tchPredictResult2\xe9\x02\n\x11PredictionService\x12\xa8\x01\n\x07Predict\x12+.google.cloud.automl.v1beta1.PredictRequest\x1a,.google.cloud.automl.v1beta1.PredictResponse"B\x82\xd3\xe4\x93\x02<"7/v1beta1/{name=projects/*/locations/*/models/*}:predict:\x01*\x12\xa8\x01\n\x0c\x42\x61tchPredict\x12\x30.google.cloud.automl.v1beta1.BatchPredictRequest\x1a\x1d.google.longrunning.Operation"G\x82\xd3\xe4\x93\x02\x41"</v1beta1/{name=projects/*/locations/*/models/*}:batchPredict:\x01*B\x9c\x01\n\x1f\x63om.google.cloud.automl.v1beta1B\x16PredictionServiceProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_annotation__payload__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__items__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_operations__pb2.DESCRIPTOR,
        google_dot_longrunning_dot_operations__pb2.DESCRIPTOR,
    ],
)


_PREDICTREQUEST_PARAMSENTRY = _descriptor.Descriptor(
    name="ParamsEntry",
    full_name="google.cloud.automl.v1beta1.PredictRequest.ParamsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.automl.v1beta1.PredictRequest.ParamsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1beta1.PredictRequest.ParamsEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=534,
    serialized_end=579,
)

_PREDICTREQUEST = _descriptor.Descriptor(
    name="PredictRequest",
    full_name="google.cloud.automl.v1beta1.PredictRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1beta1.PredictRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="payload",
            full_name="google.cloud.automl.v1beta1.PredictRequest.payload",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="params",
            full_name="google.cloud.automl.v1beta1.PredictRequest.params",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_PREDICTREQUEST_PARAMSENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=367,
    serialized_end=579,
)


_PREDICTRESPONSE_METADATAENTRY = _descriptor.Descriptor(
    name="MetadataEntry",
    full_name="google.cloud.automl.v1beta1.PredictResponse.MetadataEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.automl.v1beta1.PredictResponse.MetadataEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1beta1.PredictResponse.MetadataEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=744,
    serialized_end=791,
)

_PREDICTRESPONSE = _descriptor.Descriptor(
    name="PredictResponse",
    full_name="google.cloud.automl.v1beta1.PredictResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="payload",
            full_name="google.cloud.automl.v1beta1.PredictResponse.payload",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="metadata",
            full_name="google.cloud.automl.v1beta1.PredictResponse.metadata",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_PREDICTRESPONSE_METADATAENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=582,
    serialized_end=791,
)


_BATCHPREDICTREQUEST_PARAMSENTRY = _descriptor.Descriptor(
    name="ParamsEntry",
    full_name="google.cloud.automl.v1beta1.BatchPredictRequest.ParamsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.automl.v1beta1.BatchPredictRequest.ParamsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1beta1.BatchPredictRequest.ParamsEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=534,
    serialized_end=579,
)

_BATCHPREDICTREQUEST = _descriptor.Descriptor(
    name="BatchPredictRequest",
    full_name="google.cloud.automl.v1beta1.BatchPredictRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1beta1.BatchPredictRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="input_config",
            full_name="google.cloud.automl.v1beta1.BatchPredictRequest.input_config",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="output_config",
            full_name="google.cloud.automl.v1beta1.BatchPredictRequest.output_config",
            index=2,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="params",
            full_name="google.cloud.automl.v1beta1.BatchPredictRequest.params",
            index=3,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_BATCHPREDICTREQUEST_PARAMSENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=794,
    serialized_end=1108,
)


_BATCHPREDICTRESULT = _descriptor.Descriptor(
    name="BatchPredictResult",
    full_name="google.cloud.automl.v1beta1.BatchPredictResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1110,
    serialized_end=1130,
)

_PREDICTREQUEST_PARAMSENTRY.containing_type = _PREDICTREQUEST
_PREDICTREQUEST.fields_by_name[
    "payload"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__items__pb2._EXAMPLEPAYLOAD
)
_PREDICTREQUEST.fields_by_name["params"].message_type = _PREDICTREQUEST_PARAMSENTRY
_PREDICTRESPONSE_METADATAENTRY.containing_type = _PREDICTRESPONSE
_PREDICTRESPONSE.fields_by_name[
    "payload"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_annotation__payload__pb2._ANNOTATIONPAYLOAD
)
_PREDICTRESPONSE.fields_by_name[
    "metadata"
].message_type = _PREDICTRESPONSE_METADATAENTRY
_BATCHPREDICTREQUEST_PARAMSENTRY.containing_type = _BATCHPREDICTREQUEST
_BATCHPREDICTREQUEST.fields_by_name[
    "input_config"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2._BATCHPREDICTINPUTCONFIG
)
_BATCHPREDICTREQUEST.fields_by_name[
    "output_config"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2._BATCHPREDICTOUTPUTCONFIG
)
_BATCHPREDICTREQUEST.fields_by_name[
    "params"
].message_type = _BATCHPREDICTREQUEST_PARAMSENTRY
DESCRIPTOR.message_types_by_name["PredictRequest"] = _PREDICTREQUEST
DESCRIPTOR.message_types_by_name["PredictResponse"] = _PREDICTRESPONSE
DESCRIPTOR.message_types_by_name["BatchPredictRequest"] = _BATCHPREDICTREQUEST
DESCRIPTOR.message_types_by_name["BatchPredictResult"] = _BATCHPREDICTRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PredictRequest = _reflection.GeneratedProtocolMessageType(
    "PredictRequest",
    (_message.Message,),
    dict(
        ParamsEntry=_reflection.GeneratedProtocolMessageType(
            "ParamsEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_PREDICTREQUEST_PARAMSENTRY,
                __module__="google.cloud.automl_v1beta1.proto.prediction_service_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.PredictRequest.ParamsEntry)
            ),
        ),
        DESCRIPTOR=_PREDICTREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.prediction_service_pb2",
        __doc__="""Request message for
  [PredictionService.Predict][google.cloud.automl.v1beta1.PredictionService.Predict].
  
  
  Attributes:
      name:
          Name of the model requested to serve the prediction.
      payload:
          Required. Payload to perform a prediction on. The payload must
          match the problem type that the model was trained to solve.
      params:
          Additional domain-specific parameters, any string must be up
          to 25000 characters long.  -  For Image Classification:
          ``score_threshold`` - (float) A value from 0.0 to 1.0. When
          the model makes predictions for an image, it will only produce
          results that have at least this confidence score. The default
          is 0.5.  -  For Image Object Detection: ``score_threshold`` -
          (float) When Model    detects objects on the image, it will
          only produce bounding boxes    which have at least this
          confidence score. Value in 0 to 1 range,    default is 0.5.
          ``max_bounding_box_count`` - (int64) No more than    this
          number of bounding boxes will be returned in the response.
          Default is 100, the requested value may be limited by server.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.PredictRequest)
    ),
)
_sym_db.RegisterMessage(PredictRequest)
_sym_db.RegisterMessage(PredictRequest.ParamsEntry)

PredictResponse = _reflection.GeneratedProtocolMessageType(
    "PredictResponse",
    (_message.Message,),
    dict(
        MetadataEntry=_reflection.GeneratedProtocolMessageType(
            "MetadataEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_PREDICTRESPONSE_METADATAENTRY,
                __module__="google.cloud.automl_v1beta1.proto.prediction_service_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.PredictResponse.MetadataEntry)
            ),
        ),
        DESCRIPTOR=_PREDICTRESPONSE,
        __module__="google.cloud.automl_v1beta1.proto.prediction_service_pb2",
        __doc__="""Response message for
  [PredictionService.Predict][google.cloud.automl.v1beta1.PredictionService.Predict].
  
  
  Attributes:
      payload:
          Prediction result. Translation and Text Sentiment will return
          precisely one payload.
      metadata:
          Additional domain-specific prediction response metadata.  -
          For Image Object Detection: ``max_bounding_box_count`` -
          (int64) At    most that many bounding boxes per image could
          have been returned.  -  For Text Sentiment:
          ``sentiment_score`` - (float, deprecated) A value    between
          -1 and 1, -1 maps to least positive sentiment, while 1 maps
          to the most positive one and the higher the score, the more
          positive    the sentiment in the document is. Yet these values
          are relative to    the training data, so e.g. if all data was
          positive then -1 will be    also positive (though the least).
          The sentiment\_score shouldn't be    confused with "score" or
          "magnitude" from the previous Natural    Language Sentiment
          Analysis API.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.PredictResponse)
    ),
)
_sym_db.RegisterMessage(PredictResponse)
_sym_db.RegisterMessage(PredictResponse.MetadataEntry)

BatchPredictRequest = _reflection.GeneratedProtocolMessageType(
    "BatchPredictRequest",
    (_message.Message,),
    dict(
        ParamsEntry=_reflection.GeneratedProtocolMessageType(
            "ParamsEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_BATCHPREDICTREQUEST_PARAMSENTRY,
                __module__="google.cloud.automl_v1beta1.proto.prediction_service_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.BatchPredictRequest.ParamsEntry)
            ),
        ),
        DESCRIPTOR=_BATCHPREDICTREQUEST,
        __module__="google.cloud.automl_v1beta1.proto.prediction_service_pb2",
        __doc__="""Request message for
  [PredictionService.BatchPredict][google.cloud.automl.v1beta1.PredictionService.BatchPredict].
  
  
  Attributes:
      name:
          Name of the model requested to serve the batch prediction.
      input_config:
          Required. The input configuration for batch prediction.
      output_config:
          Required. The Configuration specifying where output
          predictions should be written.
      params:
          Additional domain-specific parameters for the predictions, any
          string must be up to 25000 characters long.  -  For Video
          Classification : ``score_threshold`` - (float) A value from
          0.0 to 1.0. When the model makes predictions for a video, it
          will    only produce results that have at least this
          confidence score. The    default is 0.5.
          ``segment_classification`` - (boolean) Set to true to
          request segment-level classification. AutoML Video
          Intelligence    returns labels and their confidence scores for
          the entire segment of    the video that user specified in the
          request configuration. The    default is "true".
          ``shot_classification`` - (boolean) Set to true to    request
          shot-level classification. AutoML Video Intelligence
          determines the boundaries for each camera shot in the entire
          segment    of the video that user specified in the request
          configuration. AutoML    Video Intelligence then returns
          labels and their confidence scores    for each detected shot,
          along with the start and end time of the    shot. WARNING:
          Model evaluation is not done for this classification    type,
          the quality of it depends on training data, but there are no
          metrics provided to describe that quality. The default is
          "false".    ``1s_interval_classification`` - (boolean) Set to
          true to request    classification for a video at one-second
          intervals. AutoML Video    Intelligence returns labels and
          their confidence scores for each    second of the entire
          segment of the video that user specified in the    request
          configuration. WARNING: Model evaluation is not done for this
          classification type, the quality of it depends on training
          data, but    there are no metrics provided to describe that
          quality. The default    is "false".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.BatchPredictRequest)
    ),
)
_sym_db.RegisterMessage(BatchPredictRequest)
_sym_db.RegisterMessage(BatchPredictRequest.ParamsEntry)

BatchPredictResult = _reflection.GeneratedProtocolMessageType(
    "BatchPredictResult",
    (_message.Message,),
    dict(
        DESCRIPTOR=_BATCHPREDICTRESULT,
        __module__="google.cloud.automl_v1beta1.proto.prediction_service_pb2",
        __doc__="""Batch predict result.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.BatchPredictResult)
    ),
)
_sym_db.RegisterMessage(BatchPredictResult)


DESCRIPTOR._options = None
_PREDICTREQUEST_PARAMSENTRY._options = None
_PREDICTRESPONSE_METADATAENTRY._options = None
_BATCHPREDICTREQUEST_PARAMSENTRY._options = None

_PREDICTIONSERVICE = _descriptor.ServiceDescriptor(
    name="PredictionService",
    full_name="google.cloud.automl.v1beta1.PredictionService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    serialized_start=1133,
    serialized_end=1494,
    methods=[
        _descriptor.MethodDescriptor(
            name="Predict",
            full_name="google.cloud.automl.v1beta1.PredictionService.Predict",
            index=0,
            containing_service=None,
            input_type=_PREDICTREQUEST,
            output_type=_PREDICTRESPONSE,
            serialized_options=_b(
                '\202\323\344\223\002<"7/v1beta1/{name=projects/*/locations/*/models/*}:predict:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="BatchPredict",
            full_name="google.cloud.automl.v1beta1.PredictionService.BatchPredict",
            index=1,
            containing_service=None,
            input_type=_BATCHPREDICTREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                '\202\323\344\223\002A"</v1beta1/{name=projects/*/locations/*/models/*}:batchPredict:\001*'
            ),
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_PREDICTIONSERVICE)

DESCRIPTOR.services_by_name["PredictionService"] = _PREDICTIONSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/column_spec.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.automl_v1beta1.proto import (
    data_stats_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__stats__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    data_types_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__types__pb2,
)


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/column_spec.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1P\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n3google/cloud/automl_v1beta1/proto/column_spec.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x32google/cloud/automl_v1beta1/proto/data_stats.proto\x1a\x32google/cloud/automl_v1beta1/proto/data_types.proto"\x84\x03\n\nColumnSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x38\n\tdata_type\x18\x02 \x01(\x0b\x32%.google.cloud.automl.v1beta1.DataType\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12:\n\ndata_stats\x18\x04 \x01(\x0b\x32&.google.cloud.automl.v1beta1.DataStats\x12X\n\x16top_correlated_columns\x18\x05 \x03(\x0b\x32\x38.google.cloud.automl.v1beta1.ColumnSpec.CorrelatedColumn\x12\x0c\n\x04\x65tag\x18\x06 \x01(\t\x1at\n\x10\x43orrelatedColumn\x12\x16\n\x0e\x63olumn_spec_id\x18\x01 \x01(\t\x12H\n\x11\x63orrelation_stats\x18\x02 \x01(\x0b\x32-.google.cloud.automl.v1beta1.CorrelationStatsB\x84\x01\n\x1f\x63om.google.cloud.automl.v1beta1P\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__stats__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__types__pb2.DESCRIPTOR,
    ],
)


_COLUMNSPEC_CORRELATEDCOLUMN = _descriptor.Descriptor(
    name="CorrelatedColumn",
    full_name="google.cloud.automl.v1beta1.ColumnSpec.CorrelatedColumn",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="column_spec_id",
            full_name="google.cloud.automl.v1beta1.ColumnSpec.CorrelatedColumn.column_spec_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="correlation_stats",
            full_name="google.cloud.automl.v1beta1.ColumnSpec.CorrelatedColumn.correlation_stats",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=491,
    serialized_end=607,
)

_COLUMNSPEC = _descriptor.Descriptor(
    name="ColumnSpec",
    full_name="google.cloud.automl.v1beta1.ColumnSpec",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1beta1.ColumnSpec.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="data_type",
            full_name="google.cloud.automl.v1beta1.ColumnSpec.data_type",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.automl.v1beta1.ColumnSpec.display_name",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="data_stats",
            full_name="google.cloud.automl.v1beta1.ColumnSpec.data_stats",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="top_correlated_columns",
            full_name="google.cloud.automl.v1beta1.ColumnSpec.top_correlated_columns",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="etag",
            full_name="google.cloud.automl.v1beta1.ColumnSpec.etag",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_COLUMNSPEC_CORRELATEDCOLUMN],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=219,
    serialized_end=607,
)

_COLUMNSPEC_CORRELATEDCOLUMN.fields_by_name[
    "correlation_stats"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__stats__pb2._CORRELATIONSTATS
)
_COLUMNSPEC_CORRELATEDCOLUMN.containing_type = _COLUMNSPEC
_COLUMNSPEC.fields_by_name[
    "data_type"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__types__pb2._DATATYPE
)
_COLUMNSPEC.fields_by_name[
    "data_stats"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_data__stats__pb2._DATASTATS
)
_COLUMNSPEC.fields_by_name[
    "top_correlated_columns"
].message_type = _COLUMNSPEC_CORRELATEDCOLUMN
DESCRIPTOR.message_types_by_name["ColumnSpec"] = _COLUMNSPEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ColumnSpec = _reflection.GeneratedProtocolMessageType(
    "ColumnSpec",
    (_message.Message,),
    dict(
        CorrelatedColumn=_reflection.GeneratedProtocolMessageType(
            "CorrelatedColumn",
            (_message.Message,),
            dict(
                DESCRIPTOR=_COLUMNSPEC_CORRELATEDCOLUMN,
                __module__="google.cloud.automl_v1beta1.proto.column_spec_pb2",
                __doc__="""Identifies the table's column, and its correlation with the column this
    ColumnSpec describes.
    
    
    Attributes:
        column_spec_id:
            The column\_spec\_id of the correlated column, which belongs
            to the same table as the in-context column.
        correlation_stats:
            Correlation between this and the in-context column.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ColumnSpec.CorrelatedColumn)
            ),
        ),
        DESCRIPTOR=_COLUMNSPEC,
        __module__="google.cloud.automl_v1beta1.proto.column_spec_pb2",
        __doc__="""A representation of a column in a relational table. When listing them,
  column specs are returned in the same order in which they were given on
  import . Used by: \* Tables
  
  
  Attributes:
      name:
          Output only. The resource name of the column specs. Form:  ``p
          rojects/{project_id}/locations/{location_id}/datasets/{dataset
          _id}/tableSpecs/{table_spec_id}/columnSpecs/{column_spec_id}``
      data_type:
          The data type of elements stored in the column.
      display_name:
          Output only. The name of the column to show in the interface.
          The name can be up to 100 characters long and can consist only
          of ASCII Latin letters A-Z and a-z, ASCII digits 0-9,
          underscores(\_), and forward slashes(/), and must start with a
          letter or a digit.
      data_stats:
          Output only. Stats of the series of values in the column. This
          field may be stale, see the ancestor's
          Dataset.tables\_dataset\_metadata.stats\_update\_time field
          for the timestamp at which these stats were last updated.
      top_correlated_columns:
          Output only. Top 10 most correlated with this column columns
          of the table, ordered by [cramers\_v][google.cloud.automl.v1be
          ta1.CorrelationStats.cramers\_v] metric. This field may be
          stale, see the ancestor's
          Dataset.tables\_dataset\_metadata.stats\_update\_time field
          for the timestamp at which these stats were last updated.
      etag:
          Used to perform consistent read-modify-write updates. If not
          set, a blind "overwrite" update happens.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ColumnSpec)
    ),
)
_sym_db.RegisterMessage(ColumnSpec)
_sym_db.RegisterMessage(ColumnSpec.CorrelatedColumn)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/table_spec.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.automl_v1beta1.proto import (
    io_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2,
)


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/table_spec.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1P\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n2google/cloud/automl_v1beta1/proto/table_spec.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a*google/cloud/automl_v1beta1/proto/io.proto"\xae\x01\n\tTableSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x13time_column_spec_id\x18\x02 \x01(\t\x12\x11\n\trow_count\x18\x03 \x01(\x03\x12\x14\n\x0c\x63olumn_count\x18\x07 \x01(\x03\x12?\n\rinput_configs\x18\x05 \x03(\x0b\x32(.google.cloud.automl.v1beta1.InputConfig\x12\x0c\n\x04\x65tag\x18\x06 \x01(\tB\x84\x01\n\x1f\x63om.google.cloud.automl.v1beta1P\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2.DESCRIPTOR,
    ],
)


_TABLESPEC = _descriptor.Descriptor(
    name="TableSpec",
    full_name="google.cloud.automl.v1beta1.TableSpec",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1beta1.TableSpec.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="time_column_spec_id",
            full_name="google.cloud.automl.v1beta1.TableSpec.time_column_spec_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="row_count",
            full_name="google.cloud.automl.v1beta1.TableSpec.row_count",
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="column_count",
            full_name="google.cloud.automl.v1beta1.TableSpec.column_count",
            index=3,
            number=7,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="input_configs",
            full_name="google.cloud.automl.v1beta1.TableSpec.input_configs",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="etag",
            full_name="google.cloud.automl.v1beta1.TableSpec.etag",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=158,
    serialized_end=332,
)

_TABLESPEC.fields_by_name[
    "input_configs"
].message_type = google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2._INPUTCONFIG
DESCRIPTOR.message_types_by_name["TableSpec"] = _TABLESPEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TableSpec = _reflection.GeneratedProtocolMessageType(
    "TableSpec",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TABLESPEC,
        __module__="google.cloud.automl_v1beta1.proto.table_spec_pb2",
        __doc__="""A specification of a relational table. The table's schema is represented
  via its child column specs. It is pre-populated as part of ImportData by
  schema inference algorithm, the version of which is a required parameter
  of ImportData InputConfig. Note: While working with a table, at times
  the schema may be inconsistent with the data in the table (e.g. string
  in a FLOAT64 column). The consistency validation is done upon creation
  of a model. Used by: \* Tables
  
  
  Attributes:
      name:
          Output only. The resource name of the table spec. Form:  ``pro
          jects/{project_id}/locations/{location_id}/datasets/{dataset_i
          d}/tableSpecs/{table_spec_id}``
      time_column_spec_id:
          column\_spec\_id of the time column. Only used if the parent
          dataset's ml\_use\_column\_spec\_id is not set. Used to split
          rows into TRAIN, VALIDATE and TEST sets such that oldest rows
          go to TRAIN set, newest to TEST, and those in between to
          VALIDATE. Required type: TIMESTAMP. If both this column and
          ml\_use\_column are not set, then ML use of all rows will be
          assigned by AutoML. NOTE: Updates of this field will instantly
          affect any other users concurrently working with the dataset.
      row_count:
          Output only. The number of rows (i.e. examples) in the table.
      column_count:
          Output only. The number of columns of the table. That is, the
          number of child ColumnSpec-s.
      input_configs:
          Output only. Input configs via which data currently residing
          in the table had been imported.
      etag:
          Used to perform consistent read-modify-write updates. If not
          set, a blind "overwrite" update happens.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TableSpec)
    ),
)
_sym_db.RegisterMessage(TableSpec)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
